## ------------------------------------------------------------------------
require(knitr)

opts_chunk$set(cache=TRUE, echo = TRUE)
opts_chunk$set(
				dev = c("png", "pdf"), 
               	dpi = 700, out.extra ='WIDTH="50%"'
               )


# Set caching
# dir.create("cache")
# opts_knit$set(cache = TRUE, cache.path = "cache/cache-") # , cache.path = "cache")

# http://stackoverflow.com/questions/10628665/how-to-set-cache-false-for-a-knitr-markdown-document-and-override-code-chunk-set

# opts_knit$get()


# http://stackoverflow.com/questions/14829791/figure-sizes-with-pandoc-conversion-from-markdown-to-docx



## ----, echo=FALSE--------------------------------------------------------
data(iris)
# ?iris


## ----, eval=FALSE--------------------------------------------------------
## str(iris)


## ------------------------------------------------------------------------
iris2 <- iris[, -5]


## ----, cache=TRUE--------------------------------------------------------
fit <- lm(Petal.Length ~ Petal.Width, data = iris2)


## ------------------------------------------------------------------------
summary(fit)
with(iris2, plot(Petal.Length ~ Petal.Width))
abline(fit, col = "darkblue", lwd = 3, lty = 4)


## ------------------------------------------------------------------------
# install.packages("pander")
require(pander)
pander(fit)


## ----, results='asis'----------------------------------------------------
# install.packages("pander")
require(pander)
panderOptions("table.style", "rmarkdown")  # Used in conjunction with the chunk setting results='asis'
pander(head(iris2))


## ------------------------------------------------------------------------
Species <- iris[, 5]
col_Species <- c("#7DB0DD",  "#86B875" , "#E495A5")
pairs(iris2, lower.panel = NULL,
		col = col_Species[as.numeric(Species)], 
		pch = 19, cex= 1.4)
par(xpd=TRUE)
legend(x=0, y=.4, cex = 2,
		legend = as.character(levels(Species)),  
		fill=col_Species)
par(xpd=NA)
# fix legend: https://stat.ethz.ch/pipermail/r-help/2001-September/015374.html


## ------------------------------------------------------------------------
hc <- hclust(dist(scale(iris2)), method = "complete")
# Turning the hclust object into a dendrogram object for plotting
dend <- as.dendrogram(hc)
# install.packages("dendextend")
require(dendextend)
col_clust <- c("burlywood4", "black", "darkgrey")
dend <- color_branches(dend, k=3, 
				col = col_clust,  groupLabels = 3:1)
dend <- color_labels(dend, col= col_Species[as.numeric(Species[order.dendrogram(dend)])])
dend <- hang.dendrogram(dend)


## ----, fig.width=10------------------------------------------------------
plot(dend)
legend("topright", cex = 1.5,
		legend = as.character(levels(Species)),  
		fill=col_Species)


## ----, eval=FALSE--------------------------------------------------------
## library(knitr)
## knit2html("output_08.rmd")
## purl("output_08.rmd")
## 
## # http://stackoverflow.com/questions/10646665/how-to-convert-r-markdown-to-html-i-e-what-does-knit-html-do-in-rstudio-0-9
## 
## 
## 


